/**
 * @module Angular
 *
 * This module provides NgModule and component for Angular integration of {@link DataView} control.
 */
import { ElementRef, AfterViewInit, OnDestroy, EventEmitter } from '@angular/core';
import { IBeforeLoadRangeEventArgs, IColumn, IColumnChangedEventArgs, IColumnReorderEventArgs, IRowReorderEventArgs, IEditingEventArgs, IFocusChangedEventArgs, IGrid, IGroupingEventArgs, ILayoutEngine, IRowClickEventArgs, ISelectionChangedEventArgs } from '@grapecity/dataviews.common';
/**
 * Angular component for {@link DataView} control
 *
 * See examples:
 * - {@sample Features/Basics/Introduction/angular Basic Data Grid}
 * - {@sample DataViews/Calendar/Calendar/angular Calendar Layout}
 * - {@sample DataViews/Card/CardLayoutEngine/angular Card Layout}
 * - {@sample DataViews/Trellis/TrellisWithGridLayout/angular Trellis Layout}
 * - {@sample DataViews/Masonry/MasonryLayout/angular Masonry Layout}
 * - {@sample DataViews/Timeline/TimelineGrouping/angular Timeline Grouping}
 */
export declare class DataViewComponent implements AfterViewInit, OnDestroy {
    private _initialized;
    private _data;
    private _cols?;
    private _config;
    private _options;
    private _groupingOptions;
    private _layout;
    /**
     * A reference to parent container
     */
    container: ElementRef<HTMLElement>;
    /**
     * An instance of {@link DataView} component
     */
    dataView: IGrid;
    /**
     * Specifies an array of objects for the grid model or a dataSource object
     */
    get data(): any;
    set data(value: any);
    /**
     * Specifies an array of column definitions to initialize the grid
     */
    get cols(): IColumn[];
    set cols(value: IColumn[]);
    /**
     * Specifies a JSON object used to deserialize the grid from
     */
    get config(): any;
    set config(value: any);
    /**
     * Specifies layout strategy. Default value is instance of {@link GridLayout} with default options
     */
    get layout(): ILayoutEngine;
    set layout(value: ILayoutEngine);
    /**
     * Specifies options of layout strategy and other common options like filtering/sorting/grouping.
     */
    get options(): any;
    set options(value: any);
    /**
     * Specifies options of grouping strategy.
     */
    get groupingOptions(): any;
    set groupingOptions(value: any);
    /**
     * Auto focus DOM container on mount.
     */
    autoFocus?: boolean;
    /**
     * This event occurs on each creation of underlying DataView component.
     */
    created: EventEmitter<IGrid>;
    /**
     * This event occurs when the user changes the selection using UI actions.
     */
    selectionChanged: EventEmitter<ISelectionChangedEventArgs>;
    /**
     * This event occurs when the focused row is changed. The event fires on [[GridLayout]] or [[HorizontalLayout]]
     */
    focusChanged: EventEmitter<IFocusChangedEventArgs>;
    /**
     * This event occurs when the user updates groups with UI actions. The event is fired before the actual update happens
     */
    grouping: EventEmitter<IGroupingEventArgs>;
    /**
     * This event occurs when clicking the row
     */
    rowClick: EventEmitter<IRowClickEventArgs>;
    /**
     * This event occurs when double-clicking the row
     */
    rowDbClick: EventEmitter<IRowClickEventArgs>;
    /**
     * This event occurs when the user starts dragging the column and before dropping the column in the column header
     */
    columnReorder: EventEmitter<IColumnReorderEventArgs>;
    /**
     * This event occurs when the user starts dragging the row and before inserting the row at new position
     */
    rowReorder: EventEmitter<IRowReorderEventArgs>;
    /**
     * This event occurs when the user changes the column visibility, pinned option, or column width, or expands or collapses the column group from UI
     */
    columnChanged: EventEmitter<IColumnChangedEventArgs>;
    /**
     * This event occurs before editing, once editing has started, before editing has ended, or editing has stopped
     */
    editing: EventEmitter<IEditingEventArgs>;
    /**
     * This event occurs before loading next data range.
     */
    beforeLoadRange: EventEmitter<IBeforeLoadRangeEventArgs>;
    /**
     * Initializes new instance of DataViewComponent
     * @param container a reference to host container
     */
    constructor(container: ElementRef<HTMLElement>);
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    createView(): void;
    destroyView(): void;
    recreateView(): void;
    registerHandlers(): void;
    unregisterHandlers(): void;
    applyOptions(forceInvalidate?: boolean): void;
}
/**
 * Angular module with {@link DataViewComponent} included for importing in an angular application
 */
export declare class DataViewModule {
}
